==> 20.0.4.0-TIV-PROSPECT-MOTCDM-IF0001.tar: patches/20.0.4.0.1.1/install.sh <==
#!/bin/ksh
#> This script will install Prospect 8.0 / Motorola CDMA RP4.0 HF01 hotfix
#> for IZ37148 - To support "Format 7B" file.
#> Usage: install.sh {-help|-install|-uninstall}
#

InstallFileset='
vendor/Motorola/BSCDO/1.3/MotoEVDO_loader/EVDO_PM/scripts/loader.sh
vendor/Motorola/BSCDO/MotoEVDO.build
'

########################################################
# set paths and files

RELEASE="20.0.4.0.1.1"
SourceDir="${FLEXPM_BASE}/patches/${RELEASE}"
SourceDir1="${FLEXPM_BASE}/patches/${RELEASE}/MotoEVDO/7.0.4.0.1.1"
BackupDir="${FLEXPM_BASE}/patches/${RELEASE}/backup/"

########################################################

### give help
  ToolName=`basename $0`
  runTime=`date '+%Y%m%d%H%M'`
  case $1 in
  -help|-usage)
    echo "${ToolName} usage information -- " 1>&2
    grep "^#> " $0 1>&2
    grep "^#>  \"" $0 1>&2
    exit 2
    ;;
  esac

# Check env settings

  if [ $# -ne 1 ]; then
    echo "Usage $0 {-help | -install | -uninstall}"
    exit;
  fi

  echo "Checking environment....."
  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
 


  
cd $SourceDir
# Source and destination directories

  case $1 in
  -install)
    echo "Installing patch..."
  if [[ -d ${BackupDir} ]]; then
           echo "Patch ${VERSION} may have been already applied. Aborting patch installation.\n"
           exit
  else
           mkdir -p -m 744 ${BackupDir}
  fi
    # Updating the NortelMTX.build file
    chmod +w ${FLEXPM_BASE}/MotoEVDO/vendor/Motorola/BSCDO/MotoEVDO.build

    echo "Registration of ${RELEASE} started."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir1}/vendor/Motorola/BSCDO/MotoEVDO.build
    [[ $? -ne 0 ]] && exit 1;


    
    echo "Files to be updated/added ..."

    cd $SourceDir1
   touch ${BackupDir}/backup_source.tar

    for f in ${InstallFileset}
    do
        echo "${FLEXPM_BASE}/MotoEVDO/${f}"
        if [[ -a ${FLEXPM_BASE}/MotoEVDO/${f} ]]; then
        # permissions
        chmod u+w ${FLEXPM_BASE}/MotoEVDO/${f}
		
        # Keep appeding files to the backup tarball 
        tar -rf ${BackupDir}/backup_source.tar $FLEXPM_BASE/MotoEVDO/${f}

        fi
        # install files
	cp -pf ${SourceDir1}/${f} ${FLEXPM_BASE}/MotoEVDO/${f}
		
	# permissions
	#chmod u-w ${FLEXPM_HOME}/${f}
	chmod u+x ${FLEXPM_BASE}/MotoEVDO/${f}
    done
 
    register complete ${SourceDir1}/vendor/Motorola/BSCDO/MotoEVDO.build

    echo "Installation completed successfully."
    ;;

  -uninstall)

  echo ""
    echo "+ Attempting to restore backup files ..."

    cd ${FLEXPM_HOME}

    if [[ -f ${BackupDir}/backup_source.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `tar -tf ${BackupDir}/backup_source.tar`
      do
         if [ -f $file ]
         then
           chmod +w $file
         fi
      done

      tar -xvf ${BackupDir}/backup_source.tar

    # Remove the component registration for this patch
      COMP_REG=`show_installed | grep 'rev 7.0.4.0.1 b1'`
      if [[ ! -z ${COMP_REG} ]]; then
sq1="select component_version_id from component_version where revision = '7.0.4.0.1' and component_id in (select component_id from component where component_name in ('MotoEVDO'))"
sq3="delete component_history where component_version_id in ( $sq1 )"
sq4="delete component_installed where component_version_id in ( $sq1 )"
sq5="delete component_version where component_version_id in ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq3};
${sq4};
${sq5};
exit;
EOF
      fi
    else
      echo "+ Backup files not found... exiting..."
      exit;
    fi
    cd ${START_DIR}

  echo "End: " `date`

  echo "Un-installation Complete."
    break
    ;; 

  * )
    echo "Unknown option"
    echo "Usage: install.sh {-help|-install|-uninstall}"
    ;;
  esac

==> 22.0.4.2-TIV-PROSPECT-MOTCDM-IF0001.tar: patches/22.0.4.2.1.1/install.sh <==
#!/bin/ksh
#> This script will install Prospect 8.0 / Motorola CDMA RP4.0 HF01 hotfix
#> for IZ37148 - To support "Format 7B" file.
#> Usage: install.sh {-help|-install|-uninstall}
#

InstallFileset='
vendor/Motorola/BSCDO/Network/moto_evdo_load_pkgb.sql
vendor/Motorola/BSCDO/MotoEVDO.build
'

########################################################
# set paths and files

RELEASE="22.0.4.2.1.1"
SourceDir="${FLEXPM_BASE}/patches/${RELEASE}"
SourceDir1="${FLEXPM_BASE}/patches/${RELEASE}/MotoEVDO/8.0.4.2.1.1"
BackupDir="${FLEXPM_BASE}/patches/${RELEASE}/backup/"

########################################################

### give help
  ToolName=`basename $0`
  runTime=`date '+%Y%m%d%H%M'`
  case $1 in
  -help|-usage)
    echo "${ToolName} usage information -- " 1>&2
    grep "^#> " $0 1>&2
    grep "^#>  \"" $0 1>&2
    exit 2
    ;;
  esac

# Check env settings

  if [ $# -ne 1 ]; then
    echo "Usage $0 {-help | -install | -uninstall}"
    exit;
  fi

  echo "Checking environment....."
  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
 


  
cd $SourceDir
# Source and destination directories

  case $1 in
  -install)
    echo "Installing patch..."
  if [[ -d ${BackupDir} ]]; then
           echo "Patch ${VERSION} may have been already applied. Aborting patch installation.\n"
           exit
  else
           mkdir -p -m 744 ${BackupDir}
  fi
    # Updating the NortelMTX.build file
    chmod +w ${FLEXPM_BASE}/MotoEVDO/vendor/Motorola/BSCDO/MotoEVDO.build

    echo "Registration of ${RELEASE} started."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir1}/vendor/Motorola/BSCDO/MotoEVDO.build
    [[ $? -ne 0 ]] && exit 1;


    
    echo "Files to be updated/added ..."

    cd $SourceDir1
   touch ${BackupDir}/backup_source.tar

    for f in ${InstallFileset}
    do
        echo "${FLEXPM_BASE}/MotoEVDO/${f}"
        if [[ -a ${FLEXPM_BASE}/MotoEVDO/${f} ]]; then
        # permissions
        chmod u+w ${FLEXPM_BASE}/MotoEVDO/${f}
		
        # Keep appeding files to the backup tarball 
        tar -rf ${BackupDir}/backup_source.tar $FLEXPM_BASE/MotoEVDO/${f}

        fi
        # install files
	cp -pf ${SourceDir1}/${f} ${FLEXPM_BASE}/MotoEVDO/${f}
		
	# permissions
	#chmod u-w ${FLEXPM_HOME}/${f}
	chmod u+x ${FLEXPM_BASE}/MotoEVDO/${f}
    done
    echo "@${FLEXPM_BASE}/MotoEVDO/vendor/Motorola/BSCDO/Network/moto_evdo_load_pkgb.sql " | sqlplus $DB_CONNECT
    register complete ${SourceDir1}/vendor/Motorola/BSCDO/MotoEVDO.build

    echo "Installation completed successfully."
    ;;

  -uninstall)

  echo ""
    echo "+ Attempting to restore backup files ..."

    cd ${FLEXPM_HOME}

    if [[ -f ${BackupDir}/backup_source.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `tar -tf ${BackupDir}/backup_source.tar`
      do
         if [ -f $file ]
         then
           chmod +w $file
         fi
      done

      tar -xvf ${BackupDir}/backup_source.tar
    echo "@${FLEXPM_BASE}/MotoEVDO/vendor/Motorola/BSCDO/Network/moto_evdo_load_pkgb.sql " | sqlplus $DB_CONNECT

    # Remove the component registration for this patch
      COMP_REG=`show_installed | grep 'rev 8.0.4.2.1 b1'`
      if [[ ! -z ${COMP_REG} ]]; then
sq1="select component_version_id from component_version where revision = '8.0.4.2.1' and component_id in (select component_id from component where component_name in ('MotoEVDO'))"
sq3="delete component_history where component_version_id in ( $sq1 )"
sq4="delete component_installed where component_version_id in ( $sq1 )"
sq5="delete component_version where component_version_id in ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq3};
${sq4};
${sq5};
exit;
EOF
      fi
    else
      echo "+ Backup files not found... exiting..."
      exit;
    fi
    cd ${START_DIR}

  echo "End: " `date`

  echo "Un-installation Complete."
    break
    ;; 

  * )
    echo "Unknown option"
    echo "Usage: install.sh {-help|-install|-uninstall}"
    ;;
  esac
